@@ -129,7 +129,7 @@ class SFTPClient:
       file_path = folder_id + '/' + selected_chunk
     self.client.get(file_path, output_folder + '/' + selected_chunk)
 
-  def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
+  def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
     if dst_folder[0] != '/':
       remote_folder = '/' + dst_folder
     else:
