@@ -173,15 +173,15 @@ class StorageClient(storage_adapter.StorageAdapter):
         else:
             raise Exception('Could not download_file', folder_id, selected_chunk, output_folder)
 
-    def _upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False):
+    def _upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, validate=False):
         ts = time.time()
-        self.client.upload_folder(dst_folder, src_folder, do_tar, do_compress)
+        self.client.upload_folder(dst_folder, src_folder, do_tar, do_compress, validate)
         print('Upload folder elapsed time', self.elapsed_time(ts, time.time()), ' seconds')
 
-    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, total_retries=4, retries_count=0, seconds_wait=0.5):
+    def upload_folder(self, dst_folder, src_folder, do_tar=False, do_compress=False, total_retries=4, retries_count=0, seconds_wait=0.5, validate=True):
         if retries_count < total_retries:
             try:
-                self._upload_folder(dst_folder, src_folder, do_tar=do_tar, do_compress=do_compress)
+                self._upload_folder(dst_folder, src_folder, do_tar=do_tar, do_compress=do_compress, validate=validate)
             except IncorrectCredentialsException as e:
                 print(e)
                 raise IncorrectCredentialsException
@@ -190,7 +190,7 @@ class StorageClient(storage_adapter.StorageAdapter):
                 time.sleep(seconds_wait)
                 retries_count = retries_count + 1
                 seconds_wait = seconds_wait * self.backoffValue
-                self.upload_folder(dst_folder, src_folder, do_tar=do_tar, do_compress=do_compress, total_retries=total_retries, retries_count=retries_count, seconds_wait=seconds_wait)
+                self.upload_folder(dst_folder, src_folder, do_tar=do_tar, do_compress=do_compress, total_retries=total_retries, retries_count=retries_count, seconds_wait=seconds_wait, validate=validate)
         else:
             raise Exception('Could not upload_folder', dst_folder, src_folder, do_tar, do_compress)
 
